@@ -16,7 +16,7 @@ class WhiteSpace(str, Enum):
     COMMASPACE = ", "
 
 
-class Join:
+class JoinWith:
     LINES = WhiteSpace.EOL.join
     SPACES = WhiteSpace.SPACE.join
     COMMA = WhiteSpace.COMMA.join
